package inmemory

import (
	"gitea.michaelthomson.dev/mthomson/habits/internal/todo/repository"
)

type InMemoryTodoRepository struct {
	db map[int64]repository.TodoRow
	id int64
}

func NewInMemoryTodoRepository() InMemoryTodoRepository {
	return InMemoryTodoRepository{
		db: make(map[int64]repository.TodoRow),
		id: 1,
	}
}


func (r *InMemoryTodoRepository) GetById(id int64) (repository.TodoRow, error) {
	todo, found := r.db[id]

	if !found {
		return todo, repository.ErrNotFound
	}

	return todo, nil
}

func (r *InMemoryTodoRepository) Create(todo repository.TodoRow) (repository.TodoRow, error) {
	todo.Id = r.id
	r.db[r.id] = todo
	r.id++

	return todo, nil
}

func (r *InMemoryTodoRepository) Update(todo repository.TodoRow) error {
	_, found := r.db[todo.Id]

	if !found {
		return repository.ErrNotFound
	}

	r.db[todo.Id] = todo

	return nil
}

func (r *InMemoryTodoRepository) Delete(id int64) error {
	_, found := r.db[id]

	if !found {
		return repository.ErrNotFound
	}

	delete(r.db, id)

	return nil
}
